<?xml version="1.0" encoding="utf-8"?><!-- -*-  mode: sgml; coding: utf-8;-*- -->

<xsl:stylesheet xmlns:fo="http://www.w3.org/1999/XSL/Format"
		xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
		xmlns:w="http://schemas.microsoft.com/office/word/2003/wordml"
		xmlns:o="urn:schemas-microsoft-com:office:office"
		xmlns:v="urn:schemas-microsoft-com:vml"
		xmlns:wx="http://schemas.microsoft.com/office/word/2003/auxHint"
		version="1.0">

<xsl:output method = "xml" indent = "yes" />

<!-- ******************************************************************************** -->
<!-- main match -->
<!-- ******************************************************************************** -->
  <xsl:template match="/">
    <book>
      <xsl:apply-templates select="w:wordDocument/w:body/wx:sect|w:wordDocument/w:body/wx:sub-section|w:wordDocument/w:body/w:p"/> 
    </book>
  </xsl:template>
  
  <xsl:template match="*">
    <xsl:apply-templates/>
  </xsl:template>

<!-- ******************************************************************************** -->
<!-- sectioning match -->
<!-- ******************************************************************************** -->

  <xsl:template match="wx:sect">
    <xsl:apply-templates/>
  </xsl:template>
  
  <xsl:template match="wx:sub-section">
    <section><xsl:apply-templates/></section>
  </xsl:template>

<!-- ******************************************************************************** -->
<!-- paragraph & lists match -->
<!-- ******************************************************************************** -->
  
  <xsl:template name='word-text'>
    <xsl:for-each select=".//w:t">
      <xsl:value-of select="."/>
    </xsl:for-each>
  </xsl:template>
  
  <xsl:template match="w:p">
    <xsl:variable name='style' select='w:pPr/w:pStyle/@w:val'/>
    <xsl:variable name='styleEN' select='/w:wordDocument/w:styles/w:style[@w:styleId=$style]/w:name/@w:val'/>
    <xsl:variable name='listlevel' select='w:pPr/w:listPr/w:ilvl/@w:val'/>
    <xsl:choose>
      <xsl:when test = "substring($styleEN,1,7)='heading'">
	<title><xsl:call-template name="word-text"/></title>
      </xsl:when> 
      <xsl:when test = "$listlevel != ''">
	<xsl:call-template name="list-print"/>
      </xsl:when> 
      <xsl:when test = "w:pPr/w:ind[@w:left > 300]">
	<blockquote><para><xsl:apply-templates/></para></blockquote>
      </xsl:when> 
      <xsl:otherwise>
	<para><xsl:apply-templates/></para>
      </xsl:otherwise> 
    </xsl:choose>
    
    <xsl:apply-templates select="w:r/w:footnote"/>
  </xsl:template>
  
  <xsl:template match="w:footnote">
    <para><emphasis role='warning'>Footnote: <xsl:apply-templates select="w:r|w:p/w:r"/></emphasis>
    </para>
  </xsl:template>

<!-- ******************************************************************************** -->
<!-- text & style match -->
<!-- ******************************************************************************** -->

  <xsl:template match="w:r">
    <xsl:choose>
      <xsl:when test = "w:tab">
	<blockquote><xsl:apply-templates select="(w:rPr|w:t|w:pict|w:sym)[1]"/></blockquote>
      </xsl:when> 
      <xsl:otherwise>
	<xsl:apply-templates select="(w:rPr|w:t|w:pict|w:sym)[1]"/>
      </xsl:otherwise> 
    </xsl:choose> 
  </xsl:template>
  
  <xsl:template match="w:rPr">
    <xsl:apply-templates select="*[1]"/>
  </xsl:template>

  <xsl:template match="w:u|w:b[not(@w:val) or @w:val!='off']|w:i|
    w:vertAlign|w:rFonts[@w:ascii='Symbol']" priority="5">
    <xsl:choose>
      <xsl:when test="name()='w:rFonts' and @w:ascii='Symbol'">
	<xsl:element name="emphasis">
	  <xsl:attribute name="role">symbol</xsl:attribute>
	  <xsl:apply-templates select="(following-sibling::*|../../w:t|../../w:pict|../../w:sym)[1]"/>
	</xsl:element>
      </xsl:when>
      <xsl:when test="name()='w:b' or name()='w:u'">
	<xsl:element name="emphasis">
	  <xsl:attribute name="role">strong</xsl:attribute>
	  <xsl:apply-templates select="(following-sibling::*|../../w:t|../../w:pict|../../w:sym)[1]"/>
	</xsl:element>
      </xsl:when>
      <xsl:when test="name()='w:i'">
	<xsl:element name="emphasis">
	  <xsl:apply-templates select="(following-sibling::*|../../w:t|../../w:pict|../../w:sym)[1]"/>
	</xsl:element>
      </xsl:when>
      <xsl:when test="name()='w:vertAlign' and @w:val='subscript'">
	<xsl:element name="subscript">
	  <xsl:apply-templates select="(following-sibling::*|../../w:t|../../w:pict|../../w:sym)[1]"/>
	</xsl:element>
      </xsl:when>
      <xsl:when test="name()='w:vertAlign' and @w:val='superscript'">
	<xsl:element name="superscript">
	  <xsl:apply-templates select="(following-sibling::*|../../w:t|../../w:pict|../../w:sym)[1]"/>
	</xsl:element>
      </xsl:when>
    </xsl:choose>
  </xsl:template>
  
  <xsl:template match="w:rPr/*">
    <xsl:apply-templates select="(following-sibling::*|../../w:t|../../w:pict|../../w:sym)[1]"/>
  </xsl:template>
  
  <xsl:template match="w:t">
    <xsl:apply-templates/>
  </xsl:template>
  
  <xsl:template match="w:sym[@w:font='Symbol']">
    <xsl:element name="emphasis">
      <xsl:attribute name="role">symbol_hex</xsl:attribute>
      <xsl:value-of select="@w:char"/>
    </xsl:element>
  </xsl:template>

<!-- ******************************************************************************** -->
<!-- images match -->
<!-- ******************************************************************************** -->
  
  <xsl:template match="w:pict">
    <xsl:choose>
      <xsl:when test="count(.//v:imagedata)>=1">
	<xsl:apply-templates select=".//v:imagedata"/>
      </xsl:when>
      <xsl:otherwise>
	<xsl:copy-of select="."/>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>
  
  <xsl:template match="v:imagedata">
    <xsl:variable name="src" select="@src"/>
    <xsl:choose>
      <xsl:when test="not(//w:binData[@w:name=$src])">
	<xsl:message terminate="no">
	  image not OK. src=<xsl:value-of select="$src"/>
	</xsl:message>
      </xsl:when>
      <xsl:otherwise>
	<mediaobject><imageobject>
	    <imagedata inlinedata="{//w:binData[@w:name=$src]}">
	      <xsl:attribute name="format">
		<xsl:choose>
		  <xsl:when test="substring(@src,string-length(@src)-2)='jpg'">jpeg</xsl:when>
		  <xsl:otherwise>
		    <xsl:value-of select="substring(@src,string-length(@src)-2)"/>
		  </xsl:otherwise>
		</xsl:choose>
	      </xsl:attribute>
	    </imagedata>
	</imageobject></mediaobject>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>
  
<!-- ******************************************************************************** -->
<!-- tables match -->
<!-- ******************************************************************************** -->

<xsl:template match="w:tbl">
<table tabstyle="">
<xsl:apply-templates/>
</table>
</xsl:template>

<xsl:template match="w:tr">
<row>
<xsl:apply-templates/>
</row>
</xsl:template>

<xsl:template match="w:tc">
<entry>
<xsl:apply-templates/>
</entry>
</xsl:template>

<!-- ******************************************************************************** -->
<!-- Template recursive-tag -->
<!-- ******************************************************************************** -->

<xsl:template name='recursive-tag'>
<xsl:param name="level" />
<xsl:param name="tag" />
<xsl:if test="$level &gt; 0">
<xsl:text disable-output-escaping="yes"><![CDATA[<]]></xsl:text>
<xsl:value-of select="$tag"/>
<xsl:text disable-output-escaping="yes"><![CDATA[>]]></xsl:text>
<xsl:call-template name="recursive-tag">
    <xsl:with-param name="level" select='-1+$level'/>
    <xsl:with-param name="tag" select="$tag"/>
</xsl:call-template>
</xsl:if>
</xsl:template>


<!-- ******************************************************************************** -->
<!-- Template 'list-print' -->
<!-- ******************************************************************************** -->
  
  <xsl:template name='list-print'>
    
    <xsl:variable name='list_level' select='w:pPr/w:listPr/w:ilvl/@w:val'/>
    <xsl:variable name='list_id' select='w:pPr/w:listPr/w:ilfo/@w:val'/>
    <xsl:variable name='lists_prefix' select='/w:wordDocument/w:lists'/>
    <xsl:variable name='listdef_id' select='$lists_prefix/w:list[@w:ilfo=$list_id]/w:ilst/@w:val'/>
    <xsl:variable name='listdef_pfx' select='$lists_prefix/w:listDef[@w:listDefId=$listdef_id]'/>
    <xsl:variable name='list_start' select='$listdef_pfx/w:lvl[@w:ilvl=$list_level]/w:start/@w:val'/>
    <xsl:variable name='list_type' select='$listdef_pfx/w:lvl[@w:ilvl=$list_level]/w:nfc/@w:val'/>
    <xsl:variable name='pos' select='position()'/>
    <xsl:variable name='prev_list_level' select='../w:p[position() &lt; $pos]/w:pPr/w:listPr[w:ilfo/@w:val=$list_id]/w:ilvl[@w:val=$list_level]/@w:val'/>
    <xsl:variable name='numeration-text' select='w:pPr/w:listPr/wx:t/@wx:val'/>
    
    <xsl:choose>
      <xsl:when test = "not($list_type) or $list_type &lt; 8 or $list_type=22">
	<xsl:variable name='numeration'>
	  <xsl:choose>
	    <xsl:when test ="$list_type=0">
	      <xsl:value-of select="'arabic'"/>
	    </xsl:when>
	    <xsl:when test ="$list_type=1">
	      <xsl:value-of select="'upperroman'"/>
	    </xsl:when>
	    <xsl:when test ="$list_type=2">
	      <xsl:value-of select="'lowerroman'"/>
	    </xsl:when>
	    <xsl:when test ="$list_type=3">
	      <xsl:value-of select="'upperalpha'"/>
	    </xsl:when>
	    <xsl:when test ="$list_type=4">
	      <xsl:value-of select="'loweralpha'"/>
	    </xsl:when>
	    <xsl:otherwise>
	      <xsl:value-of select="''"/>
	    </xsl:otherwise>
	  </xsl:choose>
	</xsl:variable>
	  
	<xsl:choose>
	  <xsl:when test = "$prev_list_level != ''">
	    <orderedlist continuation='continues' inheritnum='ignore'
	      numeration-text="{$numeration-text}" numeration="$numeration">
	      <listitem>
		<xsl:call-template name="recursive-tag">
		  <xsl:with-param name="level" select='$list_level'/>
		  <xsl:with-param name="tag" select="'blockquote'"/>
		</xsl:call-template>
		<xsl:apply-templates/>
		<xsl:call-template name="recursive-tag">
		  <xsl:with-param name="level" select='$list_level'/>
		  <xsl:with-param name="tag" select="'/blockquote'"/>
		</xsl:call-template>
	      </listitem>
	    </orderedlist>
	  </xsl:when>
	  <xsl:otherwise>
	    <orderedlist continuation='restarts' inheritnum='ignore' numeration-text="{$numeration-text}">
	      <listitem>
		<xsl:call-template name="recursive-tag">
		  <xsl:with-param name="level" select='$list_level'/>
		  <xsl:with-param name="tag" select="'blockquote'"/>
		</xsl:call-template>
		<xsl:apply-templates/>
		<xsl:call-template name="recursive-tag">
		  <xsl:with-param name="level" select='$list_level'/>
		  <xsl:with-param name="tag" select="'/blockquote'"/>
		</xsl:call-template>
	      </listitem>
	    </orderedlist>
	  </xsl:otherwise>
	</xsl:choose>
      </xsl:when>
      <xsl:otherwise>
	<itemizedlist><listitem>
	    <xsl:call-template name="recursive-tag">
	      <xsl:with-param name="level" select='$list_level'/>
	      <xsl:with-param name="tag" select="'blockquote'"/>
	    </xsl:call-template>
	    <xsl:apply-templates/>
	    <xsl:call-template name="recursive-tag">
	      <xsl:with-param name="level" select='$list_level'/>
	      <xsl:with-param name="tag" select="'/blockquote'"/>
	    </xsl:call-template>
	</listitem></itemizedlist>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>
  

</xsl:stylesheet>
