
proc printer_two_val_swap { attribute value {hdc "" } } {
  if { $hdc == "" } {
    set hdctag ""
  } else {
    set hdctag "-hDC $hdc"
  }
  set newval [ list [ lindex $value 1] [ lindex $value 0 ] ]
  eval printer attr $hdctag -set [list [ list [list "$attribute" $newval] ] ]
}
proc printer_four_val_swap { attribute value {hdc "" } } {
  if { $hdc == "" } {
    set hdctag ""
  } else {
    set hdctag "-hDC $hdc"
  }
  set newval [ list [ lindex $value 1] [ lindex $value 0 ] [lindex $value 3] [lindex $value 2] ]
  eval printer attr $hdctag -set [list [ list [list "$attribute" $newval] ] ]
}
proc printer_change_orientation { orientation { hdc "" } } {
  if { $hdc == "" } {
    set hdctag ""
  } else {
    set hdctag "-hDC $hdc"
  }
  if { $orientation == "portrait" } {
  } else {
    set orientation "landscape"
  }
  set orient [ eval printer attr $hdctag -get [list [ list "page orientation" ] ] ]
  if { $orient == "" } {
    error "This printer has no page orientation attribute"
  }
  set orient [ lindex [lindex $orient 0] 1 ]
  if { $orientation == $orient } {
  } else {
    eval printer attr $hdctag -set [ list [ list [list "page orientation" $orientation] ] ]
    set val [ eval printer attr $hdctag -get [ list [ list "page dimensions" ] ] ]
    if { $val != "" } {
      set dims [ lindex [ lindex $val 0 ] 1 ]
      set dimx [ lindex $dims 0 ]
      set dimy [ lindex $dims 1 ]
      if { "$orient" == "portrait" } {
        if { $dimx > $dimy } { return }
      } elseif { "$orient" == "landscape" } {
        if { $dimx < $dimy } { return }
      }
      printer_two_val_swap "page dimensions" $dims
    }
    set val [ eval printer attr $hdctag -get [ list [ list "printer resolution" ] ] ]
    if { $val != "" } {
      printer_two_val_swap "printer resolution" [ lindex [ lindex $val 0 ] 1 ]
    }
    set val [ eval printer attr $hdctag -get [ list [ list "page margins" ] ] ]
    if { $val != "" } {
      printer_four_val_swap "page margins" [ lindex [ lindex $val 0 ] 1 ]
    }
    set val [ eval printer attr $hdctag -get [ list [ list "page minimum margins" ] ] ]
    if { $val != "" } {
      printer_four_val_swap "page minimum margins" [ lindex [ lindex $val 0 ] 1 ]
    }
  }
}
proc all_default_attribs { {orientation landscape} { autoclose true } } {
  set pl [lsort [ printer list ] ]
  puts "Printer list:"
  foreach name $pl {
    puts "\t$name"
  }
  set ac [ printer option [ list autoclose $autoclose ] ]
  puts "Using orientation $orientation and options $ac"
  puts "Default attributes for each printer\n"
  foreach name $pl {
    puts $name
    set hdc [ printer open -name $name ]
    printer_change_orientation $orientation $hdc
    set attr [ printer attr -hDC $hdc ]
    if { $autoclose != "true" } {
      lappend hdclist $hdc
    }
    foreach pair $attr {
      puts [ format "%-20s\t%s" [lindex $pair 0 ] [ lindex $pair 1] ]
    }
    puts ""
    update idletasks
  }
  if { $autoclose == "true" } {
    printer close
  } else {
    if { [llength $hdclist] != [llength $pl] } {
      puts "Not all printers opened successfully"
    }
    foreach hdc $hdclist {
      printer close -hDC $hdc
    }
  }
  if [ catch { 
    set list [ hdc list ]
     } ]  {
  } else {
    if { [ llength $list ] > 0 } {
      puts "There are [llength list] remaining open HDCs! ($list)"
      foreach h $list { printer close -hDC $h }
    }
  }
}
proc selected_attribs { } {
  set ret [ printer dialog select ] 
  set hdc [ lindex $ret 0 ]
  if { [lindex $ret 1] == 0 } {
    puts "Printer selection canceled"
  } else {
    puts "\nAttributes for selected printer\n"
    set attr [ printer attr -hDC $hdc ]
    foreach pair $attr {
      puts [ format "%-20s\t%s" [lindex $pair 0 ] [ lindex $pair 1] ]
    }
    printer close -hDC $hdc
  }
}
