rem    OutputFile: %2\%1.flavia.inf
rem    OutputFile: %2\%1-ramsolid.info
rem    ErrorFile: %2\%1.flavia.err
rem    ErrorFile: %2\%1-ramsolid.err
rem    WarningFile: %2\%1.flavia.war

tcl
proc LaunchTdynAndRamSolid { basename dir problemtypedir } {
    global RunningProcess tcl_platform

    switch $::tcl_platform(platform) {
	"windows" { 
	    set tdynexe tdyn.exe
	    set ramexe ramseries.exe
	}
	"default" { 
	    set tdynexe tdyn
	    set ramexe ramseries
	}
    }

    foreach i [list .flavia.res .flavia.err .flavia] {
	file delete [file join $dir $basename$i]
    }
    foreach i [list .flavia.msh .flavia.res .dat .err .info .war] {
	file delete [file join $dir $basename-ramsolid$i]
    }
    file rename [file join $dir $basename.tdyn.dat] [file join $dir $basename.flavia]
    file rename [file join $dir $basename.dat] [file join $dir $basename-ramsolid.dat]
 
    for { set port 3256 } { $port <= 13256 } { incr port } {
	set err [catch { socket -server "" $port } sock]
	if { !$err } {
	    close $sock
	    break
	}
    }
    if { $port > 13256 } {
	set fout [open [file join $dir $basename.flavia.err] a]
	puts $fout "Failed to open TCP-IP port in the range 3256-13256."
	puts $fout "Contact your system administrator and check configuration of firewalls and anti-virus"
	close $fout
	return
    }

    set exe [file join $problemtypedir "exec" $tdynexe]
    set dat [file join $dir $basename.flavia]
    set out [file join $dir $basename.flavia.out]
    set err1 [file join $dir $basename.flavia.err]

    set pid1 [exec $exe -name $dat -3d -coupling $port 10000 > $out &]

    set exe [file join $problemtypedir "exec" $ramexe]
    set dat [file join $dir $basename-ramsolid.dat]
    set err2 [file join $dir $basename-ramsolid.err]

    set pid2 [exec $exe -tdyncoupling $port 10000 -a $dat &]

    set RunningProcess running
    set ErrorInProcess "no"
    while 1 {
	if { $RunningProcess == "" } {
	    if { [isalive $pid1] } {  kill $pid1 }
	    if { [isalive $pid2] } {  kill $pid2 }
	    vwait forever
	}
	if { ![isalive $pid1] & ![isalive $pid2] } { break }
	if { ![isalive $pid1] & [file exists $err1] && [file size $err1] > 0 } {
	    kill $pid2
	    set ErrorInProcess "yes"
	    break
	}
	if { ![isalive $pid2] & [file exists $err2] && [file size $err2] > 0 } {
	    kill $pid1
	    set ErrorInProcess "yes"
	    break
	}
	after 200
	update
    }

    if { $ErrorInProcess=="no" } {
	    if { ![file exists [file join $dir $basename.flavia.res]] || \
		[file size [file join $dir $basename.flavia.res]] == 0 } {
		set fout [open [file join $dir $basename.flavia.err] a]
		puts $fout "Tdyn failed. Results are not available."
		close $fout
	    }
	if { ![file exists [file join $dir $basename-ramsolid.flavia.res]]  || \
		[file size [file join $dir $basename-ramsolid.flavia.res]] == 0 } {
		set fout [open [file join $dir $basename.flavia.err] a]
		puts $fout "Ramsolid failed. Results are not available."
		close $fout
	    } else { file delete [file join $dir $basename-ramsolid.dat] }
    }

    foreach i [list .err .war] {
	set f [file join $dir $basename-ramsolid$i]
	if { [file exists $f] && [file size $f] > 0 } {
	    set fin [open $f r]
	    set fout [open [file join $dir $basename.flavia$i] a]
	    puts -nonewline $fout [read $fin]
	    close $fin
	    close $fout
	}
    }
#    set ftdyn [file join $dir $basename.flavia.res]
#    set fram [file join $dir $basename-ramsolid.flavia.res]
#    if { [file exists $ftdyn] && [file size $ftdyn] > 0 && \
#	     [file exists $fram] && [file size $fram] > 0 } {
#	set fin [open $fram r]
#	gets $fin
#	set fout [open $ftdyn a]
#	puts -nonewline $fout [read $fin]
#	close $fin
#	close $fout
#	file delete $fram
#   }
}

switch $::tcl_platform(platform) {
    "windows" { 
	foreach "- - basename dir problemtypedir -" $argv break
    }
    "default" { 
	foreach "basename dir problemtypedir" $argv break
    }
}
LaunchTdynAndRamSolid $basename $dir $problemtypedir
